CollectiveAnomalyDetector
==================================================================

.. currentmodule:: skchange.anomaly_detectors

.. autoclass:: CollectiveAnomalyDetector

.. include:: skchange.anomaly_detectors.CollectiveAnomalyDetector.examples

.. raw:: html

    <div class="clearer"></div>